<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Istnieje życie poza przeglądarką internetową!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Wersja %1</translation>
    </message>
    <message>
        <source>This is a &quot;Technology Preview&quot; release, do not expect it to be perfect.</source>
        <translation type="obsolete">To jest wydanie &quot;Technology Preview&quot; więc nie spodziewaj się, że będzie idealne.</translation>
    </message>
    <message>
        <source>Report bugs and send in your ideas to %1</source>
        <translation>Raporty o błędach oraz pomysłach ślij na adres %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 to darmowe oprogramowanie ale jego tworzenie zabiera cenny czas.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate via PayPal&lt;/a&gt; to support the continued development of %2.</source>
        <translation type="obsolete">Proszę &lt;a href=&apos;%1&apos;&gt;wspomóż finansowo przez PayPal&lt;/a&gt; prace nad programem %2.</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Ikony stworzone przez %1.</translation>
    </message>
    <message>
        <source>Compact mode contributed by %1.</source>
        <translation>Tryb kompaktowy dzięĸi %1.</translation>
    </message>
    <message>
        <source>Translated by %1</source>
        <translation>Udział w tłumaczeniu mają: %1</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Program wydany na licencji &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O programie</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>To co zawsze chciałeś wiedzieć o %1 ale bałeś się zapytać</translation>
    </message>
    <message>
        <source>HTTP proxy support contributed by %1.</source>
        <translation>Wsparcie dla HTTP proxy dzięki wkładowi %1.</translation>
    </message>
    <message>
        <source>Windows version built by %1</source>
        <translation type="obsolete">%1 - kompilacja dla Windows</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Proszę &lt;a href=&apos;%1&apos;&gt;wspomóż&lt;/a&gt; prace nad programem %2.</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Wyczyść</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation>bajtów</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation>bajtów/s</translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation>KB/s</translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation>MB/s</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>sekund</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minut</translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation>Pozostało %4 %5</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>This is just the demo version of %1.</source>
        <translation>To tylko wersja demo %1.</translation>
    </message>
    <message>
        <source>It can only download videos shorter than %1 minutes so you can test the download functionality.</source>
        <translation>Program pobiera tylko filmy krótsze od %1 minut w celu przetestowania funkcji.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Kontynuuj</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Zdobądź pełną wersję</translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Zmień położenie</translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation>Wybierz położenie pobierań</translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation>Udało się zmienić położenie pobranych filmów.</translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation>Pobrane filmy nadal będą zapisywane w poprzedniej lokalizacji.</translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation>Pobieranie do: %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation>Pobrane filmy</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Odtwórz</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Wstrzymaj</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Odtwórz/Wstrzymaj</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Zakończ odtwarzanie po tym utworze</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Następny utwór</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Poprzedni utwór</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Zwiększ głośność</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Zmniejsz głośność</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Wycisz</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Przewiń do przodu</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Przewiń do tyłu</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <source>Searching...</source>
        <translation>Szukanie...</translation>
    </message>
    <message>
        <source>Show %1 More</source>
        <translation>Pokaż następne %1</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Brak plików wideo</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Nie ma więcej filmów</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation type="obsolete">Powrót</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation type="obsolete">Wróć do poprzedniego filmu</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation></translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Zatrzymaj odtwarzanie i wróć do wyszukiwania</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>Następny</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Pomiń i włącz następny film</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pauza</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Wstrzymaj odtwarzanie</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>Pełny &amp;Ekran</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Włącz widok pełnoekranowy</translation>
    </message>
    <message>
        <source>&amp;Compact mode</source>
        <translation>Tryb kompaktowy</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Ukryj listę odtwarzania i pasek narzędziowy</translation>
    </message>
    <message>
        <source>Open the YouTube video page</source>
        <translation type="obsolete">Otwórz film YouTube w przeglądarce</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Usuń zaznaczone filmy z listy odtwarzania</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Przes&amp;uń w górę</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Przesuń do góry zaznaczone filmy na liście odtwarzania</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Przesuń w &amp;dół</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Przesuń na dół zaznaczone filmy na liście odtwarzania</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>Wyjdź</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation></translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Na razie</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>Strona domo&amp;wa</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>Strona domowa %1</translation>
    </message>
    <message>
        <source>&amp;Donate via PayPal</source>
        <translation type="obsolete">&amp;Dotacja dla twórcy przez PayPal</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Proszę, wspomóż finansowo prace nad %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>O progr&amp;amie</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Info o %1</translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation type="obsolete">Szukaj</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>Progr&amp;am</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>Lista odtwarzania</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>Film</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Otwieranie %1</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Fatalny błąd: %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Błąd: %1</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Odtwarzaj</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Wznów odtwarzanie</translation>
    </message>
    <message>
        <source>Exit &amp;Full Screen</source>
        <translation>Wyłącz &amp;pełny ekran</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation></translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Głośność %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Dźwięk jest wyłączony</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Dźwięk jest włączony</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Szukaj</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Wyłącz dźwięk</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Wciśnij %1 aby zwiększyć głośność, %2 żeby ściszyć</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Pozostały czas: %1</translation>
    </message>
    <message>
        <source>High Definition video is enabled</source>
        <translation type="obsolete">High Definition jest włączone</translation>
    </message>
    <message>
        <source>High Definition video is not enabled</source>
        <translation type="obsolete">High Definition jest wyłączone</translation>
    </message>
    <message>
        <source>The current video is in High Definition</source>
        <translation type="obsolete">Bieżący film jest dostępny w High Definition</translation>
    </message>
    <message>
        <source>The current video is not in High Definition</source>
        <translation type="obsolete">Bieżący film nie jest dostępny w High Definition</translation>
    </message>
    <message>
        <source>&amp;Clear recent keywords</source>
        <translation>&amp;Usuń ostatnie szukane słowa</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Usuń historię wyszukiwania. Operacja nie może zostać cofnięta.</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>Twoja prywatność jest teraz zapewniona</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube page</source>
        <translation>Otwórz stronę &amp;YouTube</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Idź do strony YouTube i wstrzymaj odtwarzanie</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;link</source>
        <translation>Kopiuj &amp;link YouTube</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Kopiuj bieżący link YouTube do schowka</translation>
    </message>
    <message>
        <source>Copy the video stream &amp;URL</source>
        <translation>Kopiuj &amp;URL strumienia wideo</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Kopiuj URL bieżącego strumienia wideo do schowka</translation>
    </message>
    <message>
        <source>Make a &amp;donation</source>
        <translation>Wspomóż finansowo</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>Aktualne ustawienie jakości wideo to %1</translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation>&amp;Pobrane pliku</translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation>Pokaż szczegóły pobranych filmów</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>&amp;Pobierz</translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation>Pobierz aktualnie odtwarzany film</translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>Czy chcesz zamknąć %1 z uruchomionym procesem pobierania?</translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>Jeśli zamkniesz %1, proces pobierania zostanie anulowany.</translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation>Zamknij i anuluj pobieranie</translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation>Zaczekaj do końca pobierania</translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation>Pobieranie zakończone</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Most relevant</source>
        <translation>Najbardziej trafne</translation>
    </message>
    <message>
        <source>Most recent</source>
        <translation>Najnowsze</translation>
    </message>
    <message>
        <source>Most viewed</source>
        <translation>Najpopularniejsze</translation>
    </message>
    <message>
        <source>You&apos;re watching &quot;%1&quot;</source>
        <translation>Oglądasz &quot;%1&quot;</translation>
    </message>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Teraz możesz wkleić link YouTube do innego programu</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Teraz możesz wkleić URL strumienia wideo do innego programu</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>Link będzie ważny tylko przez określony czas.</translation>
    </message>
    <message>
        <source>This is just the demo version of %1.</source>
        <translation>To tylko wersja demo %1.</translation>
    </message>
    <message>
        <source>It allows you to test the application and see if it works for you.</source>
        <translation>Pozwala przetestować aplikację i sprawdzić, czy działa.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Kontynuuj</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Zdobądź pełną wersję.</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>Pobieranie %1</translation>
    </message>
</context>
<context>
    <name>NetworkAccess</name>
    <message>
        <source>Network error: %1</source>
        <translation>Błąd sieci: %1</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <source>%1 views</source>
        <translation>%1 wyświetleń</translation>
    </message>
    <message>
        <source>%1 of %2 (%3) ? %4</source>
        <translation>%1 z %2 (%3) ? %4</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Przygotowywanie</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Nie udało się</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Zakończono</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Zatrzymano</translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation>Zatrzymaj pobieranie</translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation>Pokaż w %1</translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation>Otwórz nadrzędny folder</translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation>Restartuj pobieranie</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Szukaj</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Witaj w &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>Enter a keyword to start watching videos.</source>
        <translation>Wpisz szukane słowo i zacznij oglądać filmy.</translation>
    </message>
    <message>
        <source>Watch</source>
        <translation>Wyświetl</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Ostatnio szukane</translation>
    </message>
    <message>
        <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
        <translation>Nowa wersja %1 jest dostępna. Proszę &lt;a href=&apos;%2&apos;&gt; zaktualizuj do wersji %3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Usiądź wygodnie</translation>
    </message>
</context>
<context>
    <name>SettingsView</name>
    <message>
        <source>Preferences</source>
        <translation type="obsolete">Opcje</translation>
    </message>
    <message>
        <source>&amp;Video options</source>
        <translation type="obsolete">Opcje &amp;obrazu</translation>
    </message>
    <message>
        <source>Use high quality video when available</source>
        <translation type="obsolete">Użyj wysokiej jakości wideo, jeśli jest to możliwe</translation>
    </message>
    <message>
        <source>&amp;Saved recent keywords</source>
        <translation type="obsolete">&amp;Zapisz ostatnie słowa szukane</translation>
    </message>
    <message>
        <source>&amp;Clear recent keywords</source>
        <translation type="obsolete">&amp;Usuń ostatnie słowa szukane</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="obsolete">&amp;Zamknij</translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <source>Network error: %1 for %2</source>
        <translation>Błąd sieci: %1 dla %2</translation>
    </message>
</context>
</TS>
